// DO NOT EDIT -- generated by mk-ops.awk
#if ! defined (octave_mx_ui8nda_i16nda_h)
#define octave_mx_ui8nda_i16nda_h 1
#include "octave-config.h"
#include "uint8NDArray.h"
#include "int16NDArray.h"
  extern OCTAVE_API boolNDArray mx_el_lt (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_le (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_ge (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_gt (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_eq (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_ne (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_and (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_or (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_not_and (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_not_or (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_and_not (const uint8NDArray&, const int16NDArray&);
  extern OCTAVE_API boolNDArray mx_el_or_not (const uint8NDArray&, const int16NDArray&);
#endif
